@@ -15,9 +15,9 @@
 #' @keywords internal
 extended_range <- function(x) {
   # Combine vectors
-  zh <- data_object$zh
-  a  <- data_object$a
-  b  <- data_object$b
+  zh <- x$zh
+  a  <- x$a
+  b  <- x$b
   combined <- c(zh, a, b)
 
   # Compute min and max
